@@ -15,7 +15,7 @@ use crate::cli::NativeCommandArgs;
 use crate::cmd_output;
 
 pub mod file_api;
-pub use ::dep_cmake::*;
+pub use dep_cmake::*;
 pub use file_api::Query;
 
 /// Get all variables defined in the `cmake_script_file`.
@@ -74,8 +74,7 @@ impl TryFrom<&file_api::codemodel::target::Link> for LinkArgsBuilder {
         let linkflags = link
             .command_fragments
             .iter()
-            .map(|f| NativeCommandArgs::new(&f.fragment))
-            .flatten()
+            .flat_map(|f| NativeCommandArgs::new(&f.fragment))
             .collect();
         Ok(LinkArgsBuilder {
             linkflags,
